<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html"/>

<!-- 
Author:   Urs Roesch <urs (a) synthetik dot ch>
Version:  0.1
Based on: Konsole.xsl (http://kde-look.org/content/show.php?content=11044) 
License:  GPL (http://www.gnu.org/licenses/gpl.txt)

Changelog:
 - 2004-03-05 Urs Roesch
   * Initial code
   
Todo:
 * Cleanup
 * i18n testing
 * BiDi testing

Readme: 
   You can now configure style with xsl variables right below this message.
   Simply change the values to the ones you would like to use and in either
   your favorite text editor or the build in one of Kopete.
   
-->


<!-- User definable variables -->
<xsl:variable name="body-font-weight">bold</xsl:variable>

<!-- set the color of the timestamp -->
<xsl:variable name="contact-color">#00CF00</xsl:variable>
<!-- set the font-weight of the timestamp (see the CSS spec for more info) -->
<xsl:variable name="contact-font-weight">normal</xsl:variable>

<!-- set the color of the timestamp -->
<xsl:variable name="time-color">#CECF00</xsl:variable>
<!-- set the font-weight of the timestamp (see the CSS spec for more info) -->
<xsl:variable name="time-font-weight">normal</xsl:variable>

<!-- set the symbol for outgoing messages -->
<xsl:variable name="outgoing-symbol">$</xsl:variable>
<!-- set the color of the symbol for outgoing messages -->
<xsl:variable name="outgoing-color">#CF4600</xsl:variable>
<!-- set the font-weight of the symbol for outgoing messages -->
<xsl:variable name="outgoing-font-weight">normal</xsl:variable>

<!-- set the symbol for incoming messages -->
<xsl:variable name="incoming-symbol">$</xsl:variable>
<!-- set the color of the symbol for incoming messages --> 
<xsl:variable name="incoming-color">#CFCF00</xsl:variable>
<!-- set the font-weight for the symbol for incoming messages -->
<xsl:variable name="incoming-font-weight">normal</xsl:variable>

<!-- set the symbol for action messages -->
<xsl:variable name="action-symbol">@</xsl:variable>
<!-- set the color for the action message symbol -->
<xsl:variable name="action-color">#00CFCF</xsl:variable>
<!-- set the font-weight for the action message symbol -->
<xsl:variable name="action-font-weight">normal</xsl:variable>
<!-- set the font-color of the action messages -->
<xsl:variable name="action-body-color">darkgrey</xsl:variable>

<!-- set the symbol for internal messages -->
<xsl:variable name="internal-symbol">#</xsl:variable>
<!-- set the color for the internal message symbol -->
<xsl:variable name="internal-color">#CF00CF</xsl:variable>
<!-- set the font-weight for the internal message symbol -->
<xsl:variable name="internal-font-weight">normal</xsl:variable>

<xsl:variable name="use-meta-name">yes</xsl:variable>
<!-- set to no to override the kopete background and font-colors -->
<xsl:variable name="use-kopete-colors">yes</xsl:variable>



<!-- eof user definable user variables -->



<!-- ============================================================================================ -->
<!-- Default variables are mine; read keep your greasy paws off ;) -->
<xsl:variable name="default-background">#000000</xsl:variable>
<xsl:variable name="default-foreground">#FFFFFF</xsl:variable>

<xsl:variable name="default-time-color">#00CF00</xsl:variable>
<xsl:variable name="default-time-font-weight">normal</xsl:variable>

<xsl:variable name="default-contact-color">#00CF00</xsl:variable>
<xsl:variable name="default-contact-font-weight">normal</xsl:variable>

<xsl:variable name="default-outgoing-symbol">$</xsl:variable>
<xsl:variable name="default-outgoing-color">#CF4600</xsl:variable>
<xsl:variable name="default-outgoing-font-weight">normal</xsl:variable>

<xsl:variable name="default-incoming-symbol">$</xsl:variable>
<xsl:variable name="default-incoming-color">#CFCF00</xsl:variable>
<xsl:variable name="default-incoming-font-weight">normal</xsl:variable>

<xsl:variable name="default-action-symbol">@</xsl:variable>
<xsl:variable name="default-action-color">#00CFCF</xsl:variable>
<xsl:variable name="default-action-font-weight">bold</xsl:variable>
<xsl:variable name="default-action-body-color">darkgrey</xsl:variable>

<xsl:variable name="default-internal-symbol">#</xsl:variable>
<xsl:variable name="default-internal-color">#CF00CF</xsl:variable>
<xsl:variable name="default-internal-font-weight">bold</xsl:variable>

<xsl:variable name="lc">ltr</xsl:variable>
<xsl:variable name="uc">LTR</xsl:variable>
<!-- <xsl:variable name="text-direction">ltr</xsl:variable> -->
<xsl:variable name="text-direction"><xsl:value-of select="translate(body/@dir, $uc, $lc)" /></xsl:variable> 

<!-- let the games begin -->

<xsl:template match="message">


<div class="KopeteMessage">
	<xsl:attribute name="id">
		<xsl:value-of select="@id"/>
	</xsl:attribute>
	<xsl:attribute name="style">
		<xsl:choose>
			<xsl:when test="$use-kopete-colors = 'yes' ">
				<xsl:if test="body/@color">
					color: <xsl:value-of select="body/@color"/>;
				</xsl:if>
  				<xsl:if test="body/@bgcolor">
    					background-color: <xsl:value-of select="body/@bgcolor"/>
  				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				background-color: <xsl:value-of select="$default-background" />;
				color: <xsl:value-of select="$default-foreground" />;
			</xsl:otherwise>
		</xsl:choose>
  		<xsl:text>
			clear: both;
		</xsl:text>
	</xsl:attribute>
	<!-- 
	<xsl:attribute name="dir">
		<xsl:value-of select="body/@dir" />
	</xsl:attribute>
	-->
	
	
<div> <!-- floating info -->
	<xsl:attribute name="style">
		clear: both;
		width: 100%;
		<xsl:choose>
			<xsl:when test="$text-direction = 'ltr'">
				float: left;
			</xsl:when>
			<xsl:otherwise>
				float: right;
			</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>
	<xsl:attribute name="dir">
		<xsl:value-of select="$text-direction" />
	</xsl:attribute>
<!-- Time stamp -->
<span><!-- time -->
	<xsl:call-template name="style-attribute">
		<xsl:with-param name="color"><xsl:value-of select="$contact-color" /></xsl:with-param>
		<xsl:with-param name="font-weight"><xsl:value-of select="$contact-font-weight" /></xsl:with-param>
		<xsl:with-param name="default-color"><xsl:value-of select="$default-contact-color" /></xsl:with-param>
		<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-contact-font-weight" /></xsl:with-param>
	</xsl:call-template>
		<kopete-i18n>
			<xsl:choose>	
				<xsl:when test="$use-meta-name = 'yes'">
					%FROM_METACONTACT_DISPLAYNAME%
				</xsl:when>
				<xsl:otherwise>
					%FROM_CONTACT_DISPLAYNAME%
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>@</xsl:text>
			<xsl:call-template name="protocol-name">
				<xsl:with-param name="protocol"><xsl:value-of select="from/contact/@protocolIcon"/></xsl:with-param> 
			</xsl:call-template>
		</kopete-i18n>
	
</span><!-- eof contact  -->

<span>
	<xsl:call-template name="style-attribute">
		<xsl:with-param name="color"><xsl:value-of select="$time-color" /></xsl:with-param>
		<xsl:with-param name="font-weight"><xsl:value-of select="$time-font-weight" /></xsl:with-param>
		<xsl:with-param name="default-color"><xsl:value-of select="$default-time-color" /></xsl:with-param>
		<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-time-font-weight" /></xsl:with-param>
	</xsl:call-template>
	<kopete-i18n>
		<xsl:text> </xsl:text>
		%TIME%
	</kopete-i18n>
</span>

<!-- Choose based on message direction -->
</div><!-- eof floating info -->


<div>
	<xsl:attribute name="style">
		<xsl:choose>
			<xsl:when test="$text-direction = 'ltr'">
				/*text-indent: em; */
				float: left;
				margin-left: 1em;
				padding-bottom: 0.7ex;
			</xsl:when>
			<xsl:otherwise>
				/* text-indent: 1em; */
				float: right;
				margin-right: 1em;
				padding-bottom: 0.7ex;
			</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>
	<xsl:attribute name="dir">
		<xsl:value-of select="$text-direction" />
	</xsl:attribute>
<span>
	<xsl:attribute name="style">
		<xsl:if test="@direction = '3'"><!-- action message -->
			<xsl:choose>
				<xsl:when test="$action-body-color">
					color: <xsl:value-of select="$action-body-color" />;
				</xsl:when>
				<xsl:otherwise>
					color: <xsl:value-of select="$default-action-body-color" />;
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:attribute>
	<xsl:if test="@importance = '2'">
		<xsl:attribute name="class"><xsl:text>KopeteMessage highlight</xsl:text></xsl:attribute>
	</xsl:if>
	<xsl:call-template name="symbol" /><!-- get the symbol depending on direction -->
	<xsl:choose>
		<xsl:when test="@direction='3'"><!-- Action -->
			<kopete-i18n>&#160;%FROM_CONTACT_DISPLAYNAME% &#160;%BODY%</kopete-i18n>
		</xsl:when>
		<xsl:otherwise>
			<kopete-i18n>&#160;%BODY%</kopete-i18n>
		</xsl:otherwise>
	</xsl:choose>
</span>
</div>
</div><!-- eof message -->
</xsl:template>



<!-- Choose based on message direction -->
<xsl:template name="symbol">
<span>
<xsl:choose><!-- symbol -->
	<xsl:when test="@direction = '2'"><!--internal message-->
		<xsl:call-template name="style-attribute">
			<xsl:with-param name="color"><xsl:value-of select="$internal-color" /></xsl:with-param>
			<xsl:with-param name="font-weight"><xsl:value-of select="$internal-font-weight" /></xsl:with-param>
			<xsl:with-param name="default-color"><xsl:value-of select="$default-internal-color" /></xsl:with-param>
			<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-internal-font-weight" /></xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="$internal-symbol" />
	</xsl:when><!-- eof internal message -->
	
	<xsl:when test="@direction = '3'"><!--action message-->
		<xsl:call-template name="style-attribute">
			<xsl:with-param name="color"><xsl:value-of select="$action-color" /></xsl:with-param>
			<xsl:with-param name="font-weight"><xsl:value-of select="$action-font-weight" /></xsl:with-param>
			<xsl:with-param name="default-color"><xsl:value-of select="$default-action-color" /></xsl:with-param>
			<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-action-font-weight" /></xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="$action-symbol" />
	</xsl:when><!-- eof action message -->

	<xsl:when test="@direction = '1'"><!-- outgoing -->
		<xsl:call-template name="style-attribute">
			<xsl:with-param name="color"><xsl:value-of select="$outgoing-color" /></xsl:with-param>
			<xsl:with-param name="font-weight"><xsl:value-of select="$outgoing-font-weight" /></xsl:with-param>
			<xsl:with-param name="default-color"><xsl:value-of select="$default-outgoing-color" /></xsl:with-param>
			<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-outgoing-font-weight" /></xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="$outgoing-symbol" />
	</xsl:when><!-- eof outgoing  -->	
	
	<xsl:otherwise><!-- other messages -->
		<xsl:call-template name="style-attribute">
			<xsl:with-param name="color"><xsl:value-of select="$incoming-color" /></xsl:with-param>
			<xsl:with-param name="font-weight"><xsl:value-of select="$incoming-font-weight" /></xsl:with-param>
			<xsl:with-param name="default-color"><xsl:value-of select="$default-incoming-color" /></xsl:with-param>
			<xsl:with-param name="default-font-weight"><xsl:value-of select="$default-incoming-font-weight" /></xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="$incoming-symbol" />
	</xsl:otherwise><!-- eof other messages -->
</xsl:choose><!-- eof symbol -->
<xsl:text> </xsl:text>
</span>
</xsl:template>

<xsl:template name="style-attribute">
	<xsl:param name="color"><xsl:value-of select="color" /></xsl:param>
	<xsl:param name="font-weight"><xsl:value-of select="font-weight" /></xsl:param>
	<xsl:param name="default-color"><xsl:value-of select="default-color" /></xsl:param>
	<xsl:param name="default-font-weight"><xsl:value-of select="default-font-weight" /></xsl:param>
	
	<xsl:attribute name="style">
		<xsl:choose>
			<xsl:when test="$color">
				color: <xsl:value-of select="$color" />;
			</xsl:when>
			<xsl:otherwise>
				color: <xsl:value-of select="$default-color" />;
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$font-weight">
				font-weight: <xsl:value-of select="$font-weight" />;
			</xsl:when>
			<xsl:otherwise>
				font-weight: <xsl:value-of select="$default-font-weight" />;
			</xsl:otherwise>
		</xsl:choose>
	</xsl:attribute>
</xsl:template>

<!-- this extracts the protocol name from the icon path, obviously a very crude operation :( -->
<xsl:template name="protocol-name">
	<xsl:param name="protocol"><xsl:value-of select="protocol" /></xsl:param>	
<!--
	<xsl:variable name="_protocol">
	<xsl:choose>
		<xsl:when test="contains($protocol, '_protocol.')">
			<xsl:value-of select="substring-after(substring-before($protocol, '_protocol.'), '16/apps/')" />
		</xsl:when>
		<xsl:otherwise>
			Kopete
		</xsl:otherwise>
	</xsl:choose>
	</xsl:variable>
-->
	<xsl:choose>
		<xsl:when test="contains($protocol, 'aim')">
			<xsl:text>AIM</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'sms')">
			<xsl:text>SMS</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'yahoo')">
			<xsl:text>Yahoo!</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'msn')">
			<xsl:text>MSN</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'icq')">
			<xsl:text>ICQ</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'irc')">
			<xsl:text>IRC</xsl:text>
		</xsl:when>
		<xsl:when test="contains($protocol, 'jabber')">
			<xsl:text>Jabber</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>Kopete</xsl:text>
		</xsl:otherwise>
	
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
